\name{ihh2ihs}
\alias{ihh2ihs}
\title{Compute iHS (standardized iHH)}
\description{Compute iHS (standardized iHH).}
\usage{ihh2ihs(res_ihh, freqbin = 0.025, minmaf = 0.05)}
\arguments{
  \item{res_ihh}{A dataframe with nsnps rows and seven columns as obtained from the \code{scan_hh} function applied to the population of interest.}
  \item{freqbin}{Size of the bin to standardize log(iHHA/iHHD) according to the underlying "core" allele frequency at the focal SNP. Allele frequency bins are built from \code{minmaf} to 1-\code{minmaf} in steps of size \code{freqbin}. If \code{freqbin} is set to 0, standardization is performed
 considering each observed frequency as a discrete frequency class (useful in case of a large number of SNPs and few different haplotypes).

 If \code{freqbin} is set to an integer of 1 or greater, a corresponding number of equally sized bins are used.
}
  \item{minmaf}{SNPs with a MAF (Minor Allele Frequency) lower than \code{minmaf} are discarded from the analysis}
}
\details{iHS is calculated as described in Voight et al. (2006)}
\value{
  The returned value is a list containing two elements
  \item{res.ihs}{a dataframe with nsnps rows and four columns (Chromosome name, position of the SNP, iHS and Pvalue in a log10 scale)}
  \item{summary.class}{matrix with nclasses rows and three columns (Number of SNPs belonging to this class,position of the SNP, mean iHH in this class, standard deviation of iHH in this class)}
}
\references{
   Gautier, M. and Naves, M. (2011). Footprints of selection in the ancestral admixture of a New World
   Creole cattle breed. \emph{Molecular Ecology}, \bold{20}, 3128--3143.

   Voight, B.F. and Kudaravalli, S. and Wen, X. and Pritchard, J.K. (2006).
   A map of recent positive selection in the human genome. \emph{Plos Biology}, \bold{4}, e72.
}
\seealso{calc_ehh,scan_hh,distribplot,ihsplot}
\examples{
data(wgscan.cgu)
## results from a genome scan (44,057 SNPs)
##see ?wgscan.eut and ?wgscan.cgu for details
res.ihs<-ihh2ihs(wgscan.cgu)
}
